import { PageFactory } from "#database/factories/page_factory.ts"
import testUtils from "@adonisjs/core/services/test_utils"
import db from "@adonisjs/lucid/services/db"
import { test } from "@japa/runner"

test.group("GET /wikipedia/pages/[id]", (group) => {
  group.each.setup(async () => {
    return await testUtils.db().truncate()
  })

  test("should succeeds and get the page with the given id, and get all its internal links", async ({
    client,
  }) => {
    // Arrange - Given
    const page = await PageFactory.create()
    const pages = await PageFactory.createMany(10)
    const internalLinksPages = pages.slice(0, 5)
    await Promise.all(
      internalLinksPages.map(async (internalLinkPage) => {
        await db.table("internal_links").insert({
          from_page_id: page.id,
          to_page_id: internalLinkPage.id,
        })
      }),
    )

    // Act - When
    const response = await client.get(`/wikipedia/pages/${page.id}`)

    // Assert - Then
    response.assertStatus(200)
    response.assertBody({
      ...page.toJSON(),
      internalLinks: internalLinksPages.map((page) => {
        return page.toJSON()
      }),
    })
  })

  test("should fails with a 404 status code when the page with the given id does not exist", async ({
    client,
  }) => {
    // Arrange - Given
    const page = await PageFactory.create()

    // Act - When
    const response = await client.get(`/wikipedia/pages/${page.id + 1}`)

    // Assert - Then
    response.assertStatus(404)
  })
})
