import Page from "#app/models/page.ts"
import { throttle } from "#start/limiter.ts"
import type { HttpContext } from "@adonisjs/core/http"
import router from "@adonisjs/core/services/router"
import vine from "@vinejs/vine"

const requestValidator = vine.compile(
  vine.object({
    params: vine.object({
      id: vine.number().withoutDecimals().positive(),
    }),
  }),
)

class Controller {
  public async handle(context: HttpContext): Promise<Page> {
    const payload = await context.request.validateUsing(requestValidator)
    const page = await Page.findOrFail(payload.params.id)
    await page.load("internalLinks")
    return page
  }
}

router.get("/wikipedia/pages/:id", [Controller]).use(throttle)
