import Page from "#app/models/page.ts"
import { PageFactory } from "#database/factories/page_factory.ts"
import testUtils from "@adonisjs/core/services/test_utils"
import { test } from "@japa/runner"

test.group("GET /wikipedia/pages", (group) => {
  group.each.setup(async () => {
    return await testUtils.db().truncate()
  })

  test("should succeeds and get the page with the given title", async ({
    client,
  }) => {
    // Arrange - Given
    const page = await PageFactory.create()
    await PageFactory.createMany(10)

    // Act - When
    const searchParams = new URLSearchParams({ title: page.title })
    const response = await client.get(
      `/wikipedia/pages?${searchParams.toString()}`,
    )

    // Assert - Then
    response.assertStatus(200)
    response.assertBody([page.toJSON()])
  })

  test("should succeeds and get the pages with title that starts with the title given and limit", async ({
    client,
    assert,
  }) => {
    // Arrange - Given
    const limit = 4
    const title = "No"
    const pagesMatching = await Page.createMany([
      { title: "Node.ts" },
      { title: "North_America" },
      { title: "NoSQL" },
      { title: "No" },
      { title: "Nobel_Prize" },
      { title: "Norway" },
    ])
    await Page.createMany([{ title: "Linux" }, { title: "Abc" }])

    // Act - When
    const searchParams = new URLSearchParams({
      title,
      limit: limit.toString(),
    })
    const response = await client.get(
      `/wikipedia/pages?${searchParams.toString()}`,
    )
    const responseBody = response.body()

    // Assert - Then
    response.assertStatus(200)
    response.assertBody(
      pagesMatching.slice(0, limit).map((page) => {
        return page.toJSON()
      }),
    )
    assert.equal(responseBody.length, limit)
  })

  test('should fails when "title" is not provided', async ({ client }) => {
    // Act - When
    const response = await client.get("/wikipedia/pages")

    // Assert - Then
    response.assertStatus(422)
  })

  test('should fails when "limit" is too high (more than 100)', async ({
    client,
  }) => {
    // Arrange - Given
    const title = "No"
    const limit = 101

    // Act - When
    const searchParams = new URLSearchParams({
      title,
      limit: limit.toString(),
    })
    const response = await client.get(
      `/wikipedia/pages?${searchParams.toString()}`,
    )

    // Assert - Then
    response.assertStatus(422)
  })
})
