/**
 * Capitalize the first letter of a string.
 * @param string
 * @returns
 * @example capitalize("hello, world!") // "Hello, world!"
 */
export const capitalize = (string: string): string => {
  return string.charAt(0).toUpperCase() + string.slice(1)
}

/**
 * Trim any of the specified characters from the start and end of a string.
 * @param string
 * @param characters
 * @returns
 * @example trimAny("_____foo bar  ", [" ", "_"]) // "foo bar"
 */
export const trimAny = (string: string, characters: string[]): string => {
  let start = 0
  let end = string.length

  while (
    start < end &&
    (characters as Array<string | undefined>).includes(string[start])
  ) {
    start += 1
  }

  while (
    end > start &&
    (characters as Array<string | undefined>).includes(string[end - 1])
  ) {
    end -= 1
  }

  return start > 0 || end < string.length
    ? string.substring(start, end)
    : string
}

/**
 * Reduces consecutive occurrences of specified characters in a string to a single occurrence.
 *
 * @param input
 * @param characters
 * @returns
 * @example reduceConsecutiveCharacters("Hello___there!!", ["_", "!"]) // "Hello_there!"
 */
export const reduceConsecutiveCharacters = (
  input: string,
  characters: string[],
): string => {
  let result = ""
  let previousCharacter = ""
  for (const currentCharacter of input) {
    if (characters.includes(currentCharacter)) {
      if (currentCharacter !== previousCharacter) {
        result += currentCharacter
      }
    } else {
      result += currentCharacter
    }
    previousCharacter = currentCharacter
  }
  return result
}
